@@ -1,4 +1,3 @@
-
 class Resources(object):
 
     _activity = r'activity_stream/\d+/'
@@ -66,9 +65,6 @@ class Resources(object):
     _inventory_related_root_groups = r'inventories/\d+/root_groups/'
     _inventory_related_script = r'inventories/\d+/script/'
     _inventory_related_update_inventory_sources = r'inventories/\d+/update_inventory_sources/'
-    _inventory_script = r'inventory_scripts/\d+/'
-    _inventory_script_copy = r'inventory_scripts/\d+/copy/'
-    _inventory_scripts = 'inventory_scripts/'
     _inventory_source = r'inventory_sources/\d+/'
     _inventory_source_schedule = r'inventory_sources/\d+/schedules/\d+/'
     _inventory_source_schedules = r'inventory_sources/\d+/schedules/'
